Integrated Optical PUFs
=======================

pypuf ships a very basic simulation of integrated optical PUFs [RHUWDFJ13]_.

.. autoclass::
    pypuf.simulation.IntegratedOpticalPUF
    :members: __init__, eval
